#
# spec file for package xcoral
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xcoral
Version:        3.50.2
Release:        2.2
Summary:        X11 Editor with C/C++/Java Browser
License:        GPL-2.0-or-later
Group:          Productivity/Text/Editors
URL:            http://xcoral.free.fr/
Source:         http://xcoral.free.fr/xcoral-%{version}.tar.gz
Patch0:         xcoral-compile.patch
Patch1:         0001-Fix-to-compile-with-latest-gcc-14.2.1.patch
BuildRequires:  libXft-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xt)
Provides:       xcoral21

%description
Xcoral provides support for working with C, C++, Java, Perl, Ada, and
Fortran programs and for the creation of LaTeX and HTML documents.
With the help of the built-in "SMall Ansi C Interpreter" (SMAC),
xcoral can be configured and extended in almost arbitrary ways.
Examples can be found in the directory %{_prefix}/lib/xcoral. It has
a built-in C/C++/Java browser

Further information about Xcoral and SMAC is available in the detailed
online help system (also available Postscript format).

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%configure
# parallel build fails
%make_build --jobs=1

%install
install -d %{buildroot}%{_libdir}/%{name}
%make_install \
  prefix=%{buildroot}%{_prefix} \
  exec_prefix=%{buildroot}%{_prefix} \
  X_BINDIR=%{buildroot}%{_bindir} \
  XC_LIBDIR=%{buildroot}%{_libdir}/%{name}
find Doc "(" -name "*.ps" -o -name "*.pdf" ")" -exec bzip2 {} +
install -Dpm 0644 SmacLib/xcoralrc.lf \
  %{buildroot}%{_sysconfdir}/skel/.xcoralrc

%files
%doc Doc/*
%config(noreplace) %{_sysconfdir}/skel/.xcoralrc
%{_bindir}/xcoral
%{_libdir}/xcoral

%changelog
* Tue Nov  5 2024 Michael Andres <ma@suse.com>
- Add 0001-Fix-to-compile-with-latest-gcc-14.2.1.patch
  to compile.
* Thu May  6 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 3.50.2
  * Corrects a permission issue on the configure file
  * Update of the doc
  * Fix update of the chained list of color elements after a delete
* Mon Aug 31 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.49.8:
  * this new release uses TrueType/Type1 fonts to replace the old X11 fonts
- update xcoral-compile.patch: refresh
* Mon Jun  8 2020 ma@suse.com
- Update to version 3.49.6
* Thu Feb 20 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.48-8:
  * No upstream changelog available
- Drop no longer needed patches:
  * xcoral-3.47.configure.diff
  * xcoral-arraysubscript.patch
* Sat Mar 17 2018 jengelh@inai.de
- Ensure neutrality of description.
- Compact bzip2 call.
* Fri Mar 16 2018 mpluskal@suse.com
- Modernise spec file with spec-cleaner
* Thu Mar 15 2018 crrodriguez@opensuse.org
- remove xorg-x11-devel from buildrequires
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Wed Nov  5 2008 meissner@suse.de
- use RPM_OPT_FLAGS, fixed all check_gcc_output errors and warnings.
* Mon May 26 2008 ma@suse.de
- Version 3.47
- Fix using an outdated /etc/skel/.xcoralrc. Use the one included
  in the tarball.
* Wed Dec  5 2007 ro@suse.de
- move /etc/skel/.xcoralrc here
* Fri Jan 26 2007 ma@suse.de
- Fixed array subscript out of range (#152845).
* Wed Jan 24 2007 ro@suse.de
- move from /usr/X11R6 to /usr
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov  8 2005 dmueller@suse.de
- don't build as root
* Wed Apr 27 2005 ro@suse.de
- build with gcc-4
* Mon Sep 15 2003 ma@suse.de
- Version 3.42b, fixes segfault when used with KDE-3.1.1.
* Mon Feb 24 2003 ma@suse.de
- Version 3.42, fixes several bugs.
* Thu Sep 19 2002 ma@suse.de
- New Version 3.40
* Tue Oct 30 2001 ma@suse.de
- fixed missing refresh of toolbar if was obscured by popup menu.
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Mon Mar 12 2001 uli@suse.de
- added xf86 to neededforbuild
* Tue Oct 31 2000 ma@suse.de
- removed group unsorted
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Sep  9 1999 bs@suse.de
- fixed call of Check at the end of %%install section
* Mon Jan 25 1999 ma@suse.de
- Zip all "documentation.ps"
* Thu Dec 10 1998 ma@suse.de
- New Version 3.2
* Sat Sep 19 1998 ro@suse.de
- dont redeclare sys_errlist for glibc
* Wed Aug 26 1998 ma@suse.de
- New Version 3.14
- Minor fixes for window geometry handling
- Minor fixes for backspace/delete handling, documentation
  updated
* Tue Oct 21 1997 ma@suse.de
- spec file provided
* Thu Jun 12 1997 hf@suse.de
  New Version 3.1
  Fixed the Backspace - Delete problem in sourcecode.
